spannertools
============

.. automodule:: abjad.tools.spannertools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.spannertools.Beam.Beam
      ~abjad.tools.spannertools.ComplexBeam.ComplexBeam
      ~abjad.tools.spannertools.Crescendo.Crescendo
      ~abjad.tools.spannertools.Decrescendo.Decrescendo
      ~abjad.tools.spannertools.DuratedComplexBeam.DuratedComplexBeam
      ~abjad.tools.spannertools.DynamicTextSpanner.DynamicTextSpanner
      ~abjad.tools.spannertools.Glissando.Glissando
      ~abjad.tools.spannertools.Hairpin.Hairpin
      ~abjad.tools.spannertools.HiddenStaffSpanner.HiddenStaffSpanner
      ~abjad.tools.spannertools.HorizontalBracketSpanner.HorizontalBracketSpanner
      ~abjad.tools.spannertools.MeasuredComplexBeam.MeasuredComplexBeam
      ~abjad.tools.spannertools.MultipartBeam.MultipartBeam
      ~abjad.tools.spannertools.OctavationSpanner.OctavationSpanner
      ~abjad.tools.spannertools.PhrasingSlur.PhrasingSlur
      ~abjad.tools.spannertools.PianoPedalSpanner.PianoPedalSpanner
      ~abjad.tools.spannertools.Slur.Slur
      ~abjad.tools.spannertools.Spanner.Spanner
      ~abjad.tools.spannertools.StaffLinesSpanner.StaffLinesSpanner
      ~abjad.tools.spannertools.TextScriptSpanner.TextScriptSpanner
      ~abjad.tools.spannertools.TextSpanner.TextSpanner
      ~abjad.tools.spannertools.Tie.Tie
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.spannertools.make_colored_text_spanner_with_nibs.make_colored_text_spanner_with_nibs
      ~abjad.tools.spannertools.make_dynamic_spanner_below_with_nib_at_right.make_dynamic_spanner_below_with_nib_at_right
      ~abjad.tools.spannertools.make_solid_text_spanner_with_nib.make_solid_text_spanner_with_nib
